@@ -20,7 +20,9 @@ NULL
 #'  or \code{\link[ggplot2:continuous_scale]{continuous}} scale.
 #' @author N. Frerebeau
 #' @keywords internal
+#' @noRd
 scale <- function(aesthetics, scale_name, reverse = FALSE, midpoint = 0, ...) {
+  require_ggplot2()
   # Get colour palette and scheme information
   palette <- colour(scale_name, reverse, names = FALSE)
   type <- attr(palette, "type")
@@ -54,7 +56,6 @@ scale <- function(aesthetics, scale_name, reverse = FALSE, midpoint = 0, ...) {
 }
 
 # COPY FROM GGPLOT2 NON-EXPORTS
-#' @importFrom scales rescale_mid
 #' @keywords internal
 #' @noRd
 mid_rescaler <- function(mid) {
@@ -62,3 +63,11 @@ mid_rescaler <- function(mid) {
     scales::rescale_mid(x, to, from, mid)
   }
 }
+
+#' @keywords internal
+#' @noRd
+require_ggplot2 <- function() {
+  if (!requireNamespace("ggplot2", quietly = TRUE))
+    stop("Package \"ggplo2\" needed for this function to work.\n",
+         "Please install it.", call. = FALSE)
+}
